@@ -137,7 +137,7 @@ eNormal_trunc_ab <- function(X,w, method ="numerical.MLE",...){
 				  )
   
   est.par.se <- try(sqrt(diag(solve(attributes(est.par)$nll.hessian))),silent=TRUE)
-  if(class(est.par.se) == "try-error") {
+  if(inherits(est.par.se, "try-error")) {
     est.par.se <- rep(NA, length(est.par))
   } 
 } 
